@@ -269,6 +269,9 @@ INTERNALERROR_TKEAPIFAILEDOPERATION = 'InternalError.TkeApiFailedOperation'
 # TSF应用性能管理业务日志配置与应用关联处理错误。
 INTERNALERROR_TSFAPMBUSILOGCFGAPPRELATIONMASTERERROR = 'InternalError.TsfApmBusiLogCfgAppRelationMasterError'
 
+# TSF应用性能管理调用tsf-ms模块失败。
+INTERNALERROR_TSFAPMCALLTSFMSFAILED = 'InternalError.TsfApmCallTsfMsFailed'
+
 # TSF应用性能管理通用异常。
 INTERNALERROR_TSFAPMCOMMONERROR = 'InternalError.TsfApmCommonError'
 
@@ -896,6 +899,9 @@ RESOURCENOTFOUND_GROUPNOTEXIST = 'ResourceNotFound.GroupNotExist'
 # 无法获取机器信息。
 RESOURCENOTFOUND_INSTANCENOTEXIST = 'ResourceNotFound.InstanceNotExist'
 
+# [%s]模块未提供该接口[%s]。。
+RESOURCENOTFOUND_INTERFACENOTFOUND = 'ResourceNotFound.InterfaceNotFound'
+
 # 无法找到License服务器。
 RESOURCENOTFOUND_LICENSESERVERNOTFOUND = 'ResourceNotFound.LicenseServerNotFound'
 
